@@ -67,7 +67,7 @@ class App:
 
     def load(self):
         self.__load_models()
-        # asyncio.run(self.__load_migrations_table())
+        asyncio.run(self.__load_migrations_table())
 
     async def async_load(self):
         self.__load_models()
@@ -89,26 +89,30 @@ class App:
 
     @staticmethod
     async def __load_migrations_table():
-        from jija_orm.migrator import templates as migration_templates
+        from jija_orm.migrator import templates
+        from jija_orm.executors import operators, comparators
 
         executor = executors.Executor(
             'pg_catalog.pg_tables',
-            templates.Select(name='tablename'),
-            templates.Where(tablename='jija_orm',
-                            schemaname__not='pg_catalog\' and schemaname != \'information_schema'),
+            operators.Select(name='tablename'),
+            operators.Where(
+                comparators.Not('schemaname', 'pg_catalog'),
+                comparators.Not('schemaname', 'information_schema'),
+                tablename='jija_orm',
+            ),
             use_model=False
         )
 
         if len(await executor.execute()) == 0:
-            migration = migration_templates.ModelMigration(
-                'jija_orm', migration_templates.Action.CREATE,
+            migration = templates.ModelMigration(
+                'jija_orm', templates.Action.CREATE,
                 [
-                    migration_templates.FieldMigration(
-                        'id', migration_templates.Action.CREATE,
+                    templates.FieldMigration(
+                        'id', templates.Action.CREATE,
                         [
-                            migration_templates.AttributeMigration('pk', True),
-                            migration_templates.AttributeMigration('null', False),
-                            migration_templates.AttributeMigration('type', 'int8')
+                            templates.AttributeMigration('pk', True),
+                            templates.AttributeMigration('null', False),
+                            templates.AttributeMigration('type', 'int8')
                         ]
                     )
                 ],
